# frozen_string_literal: true

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Auto-generated by gapic-generator-ruby. DO NOT EDIT!

require "google/cloud/errors"
require "google/cloud/dataproc/v1beta2/clusters_pb"

module Google
  module Cloud
    module Dataproc
      module V1beta2
        module ClusterController
          ##
          # Client for the ClusterController service.
          #
          # The ClusterControllerService provides methods to manage clusters
          # of Compute Engine instances.
          #
          class Client
            include Paths

            # @private
            attr_reader :cluster_controller_stub

            ##
            # Configure the ClusterController Client class.
            #
            # See {::Google::Cloud::Dataproc::V1beta2::ClusterController::Client::Configuration}
            # for a description of the configuration fields.
            #
            # ## Example
            #
            # To modify the configuration for all ClusterController clients:
            #
            #     ::Google::Cloud::Dataproc::V1beta2::ClusterController::Client.configure do |config|
            #       config.timeout = 10.0
            #     end
            #
            # @yield [config] Configure the Client client.
            # @yieldparam config [Client::Configuration]
            #
            # @return [Client::Configuration]
            #
            def self.configure
              @configure ||= begin
                namespace = ["Google", "Cloud", "Dataproc", "V1beta2"]
                parent_config = while namespace.any?
                                  parent_name = namespace.join "::"
                                  parent_const = const_get parent_name
                                  break parent_const.configure if parent_const.respond_to? :configure
                                  namespace.pop
                                end
                default_config = Client::Configuration.new parent_config

                default_config.rpcs.create_cluster.timeout = 300.0
                default_config.rpcs.create_cluster.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config.rpcs.update_cluster.timeout = 300.0
                default_config.rpcs.update_cluster.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config.rpcs.delete_cluster.timeout = 300.0
                default_config.rpcs.delete_cluster.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config.rpcs.get_cluster.timeout = 300.0
                default_config.rpcs.get_cluster.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [13, 4, 14]
                }

                default_config.rpcs.list_clusters.timeout = 300.0
                default_config.rpcs.list_clusters.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [13, 4, 14]
                }

                default_config.rpcs.diagnose_cluster.timeout = 300.0
                default_config.rpcs.diagnose_cluster.retry_policy = {
                  initial_delay: 0.1,
                  max_delay: 60.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config
              end
              yield @configure if block_given?
              @configure
            end

            ##
            # Configure the ClusterController Client instance.
            #
            # The configuration is set to the derived mode, meaning that values can be changed,
            # but structural changes (adding new fields, etc.) are not allowed. Structural changes
            # should be made on {Client.configure}.
            #
            # See {::Google::Cloud::Dataproc::V1beta2::ClusterController::Client::Configuration}
            # for a description of the configuration fields.
            #
            # @yield [config] Configure the Client client.
            # @yieldparam config [Client::Configuration]
            #
            # @return [Client::Configuration]
            #
            def configure
              yield @config if block_given?
              @config
            end

            ##
            # Create a new ClusterController client object.
            #
            # ## Examples
            #
            # To create a new ClusterController client with the default
            # configuration:
            #
            #     client = ::Google::Cloud::Dataproc::V1beta2::ClusterController::Client.new
            #
            # To create a new ClusterController client with a custom
            # configuration:
            #
            #     client = ::Google::Cloud::Dataproc::V1beta2::ClusterController::Client.new do |config|
            #       config.timeout = 10.0
            #     end
            #
            # @yield [config] Configure the ClusterController client.
            # @yieldparam config [Client::Configuration]
            #
            def initialize
              # These require statements are intentionally placed here to initialize
              # the gRPC module only when it's required.
              # See https://github.com/googleapis/toolkit/issues/446
              require "gapic/grpc"
              require "google/cloud/dataproc/v1beta2/clusters_services_pb"

              # Create the configuration object
              @config = Configuration.new Client.configure

              # Yield the configuration if needed
              yield @config if block_given?

              # Create credentials
              credentials = @config.credentials
              # Use self-signed JWT if the scope and endpoint are unchanged from default,
              # but only if the default endpoint does not have a region prefix.
              enable_self_signed_jwt = @config.scope == Client.configure.scope &&
                                       @config.endpoint == Client.configure.endpoint &&
                                       !@config.endpoint.split(".").first.include?("-")
              credentials ||= Credentials.default scope: @config.scope,
                                                  enable_self_signed_jwt: enable_self_signed_jwt
              if credentials.is_a?(String) || credentials.is_a?(Hash)
                credentials = Credentials.new credentials, scope: @config.scope
              end
              @quota_project_id = @config.quota_project
              @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

              @operations_client = Operations.new do |config|
                config.credentials = credentials
                config.endpoint = @config.endpoint
              end

              @cluster_controller_stub = ::Gapic::ServiceStub.new(
                ::Google::Cloud::Dataproc::V1beta2::ClusterController::Stub,
                credentials:  credentials,
                endpoint:     @config.endpoint,
                channel_args: @config.channel_args,
                interceptors: @config.interceptors
              )
            end

            ##
            # Get the associated client for long-running operations.
            #
            # @return [::Google::Cloud::Dataproc::V1beta2::ClusterController::Operations]
            #
            attr_reader :operations_client

            # Service calls

            ##
            # Creates a cluster in a project. The returned
            # {::Google::Longrunning::Operation#metadata Operation.metadata} will be
            # [ClusterOperationMetadata](https://cloud.google.com/dataproc/docs/reference/rpc/google.cloud.dataproc.v1beta2#clusteroperationmetadata).
            #
            # @overload create_cluster(request, options = nil)
            #   Pass arguments to `create_cluster` via a request object, either of type
            #   {::Google::Cloud::Dataproc::V1beta2::CreateClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Dataproc::V1beta2::CreateClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload create_cluster(project_id: nil, region: nil, cluster: nil, request_id: nil)
            #   Pass arguments to `create_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param project_id [::String]
            #     Required. The ID of the Google Cloud Platform project that the cluster
            #     belongs to.
            #   @param region [::String]
            #     Required. The Dataproc region in which to handle the request.
            #   @param cluster [::Google::Cloud::Dataproc::V1beta2::Cluster, ::Hash]
            #     Required. The cluster to create.
            #   @param request_id [::String]
            #     Optional. A unique id used to identify the request. If the server
            #     receives two
            #     {::Google::Cloud::Dataproc::V1beta2::CreateClusterRequest CreateClusterRequest}
            #     requests  with the same id, then the second request will be ignored and the
            #     first {::Google::Longrunning::Operation google.longrunning.Operation} created
            #     and stored in the backend is returned.
            #
            #     It is recommended to always set this value to a
            #     [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier).
            #
            #     The id must contain only letters (a-z, A-Z), numbers (0-9),
            #     underscores (_), and hyphens (-). The maximum length is 40 characters.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::Operation]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::Operation]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def create_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1beta2::CreateClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.create_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Dataproc::V1beta2::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "project_id" => request.project_id,
                "region" => request.region
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.create_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.create_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @cluster_controller_stub.call_rpc :create_cluster, request, options: options do |response, operation|
                response = ::Gapic::Operation.new response, @operations_client, options: options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Updates a cluster in a project. The returned
            # {::Google::Longrunning::Operation#metadata Operation.metadata} will be
            # [ClusterOperationMetadata](https://cloud.google.com/dataproc/docs/reference/rpc/google.cloud.dataproc.v1beta2#clusteroperationmetadata).
            #
            # @overload update_cluster(request, options = nil)
            #   Pass arguments to `update_cluster` via a request object, either of type
            #   {::Google::Cloud::Dataproc::V1beta2::UpdateClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Dataproc::V1beta2::UpdateClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload update_cluster(project_id: nil, region: nil, cluster_name: nil, cluster: nil, graceful_decommission_timeout: nil, update_mask: nil, request_id: nil)
            #   Pass arguments to `update_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param project_id [::String]
            #     Required. The ID of the Google Cloud Platform project the
            #     cluster belongs to.
            #   @param region [::String]
            #     Required. The Dataproc region in which to handle the request.
            #   @param cluster_name [::String]
            #     Required. The cluster name.
            #   @param cluster [::Google::Cloud::Dataproc::V1beta2::Cluster, ::Hash]
            #     Required. The changes to the cluster.
            #   @param graceful_decommission_timeout [::Google::Protobuf::Duration, ::Hash]
            #     Optional. Timeout for graceful YARN decomissioning. Graceful
            #     decommissioning allows removing nodes from the cluster without
            #     interrupting jobs in progress. Timeout specifies how long to wait for jobs
            #     in progress to finish before forcefully removing nodes (and potentially
            #     interrupting jobs). Default timeout is 0 (for forceful decommission), and
            #     the maximum allowed timeout is 1 day (see JSON representation of
            #     [Duration](https://developers.google.com/protocol-buffers/docs/proto3#json)).
            #
            #     Only supported on Dataproc image versions 1.2 and higher.
            #   @param update_mask [::Google::Protobuf::FieldMask, ::Hash]
            #     Required. Specifies the path, relative to `Cluster`, of
            #     the field to update. For example, to change the number of workers
            #     in a cluster to 5, the `update_mask` parameter would be
            #     specified as `config.worker_config.num_instances`,
            #     and the `PATCH` request body would specify the new value, as follows:
            #
            #         {
            #           "config":{
            #             "workerConfig":{
            #               "numInstances":"5"
            #             }
            #           }
            #         }
            #
            #     Similarly, to change the number of preemptible workers in a cluster to 5,
            #     the `update_mask` parameter would be
            #     `config.secondary_worker_config.num_instances`, and the `PATCH` request
            #     body would be set as follows:
            #
            #         {
            #           "config":{
            #             "secondaryWorkerConfig":{
            #               "numInstances":"5"
            #             }
            #           }
            #         }
            #     <strong>Note:</strong> currently only the following fields can be updated:
            #
            #     <table>
            #     <tr>
            #     <td><strong>Mask</strong></td><td><strong>Purpose</strong></td>
            #     </tr>
            #     <tr>
            #     <td>labels</td><td>Updates labels</td>
            #     </tr>
            #     <tr>
            #     <td>config.worker_config.num_instances</td><td>Resize primary worker
            #     group</td>
            #     </tr>
            #     <tr>
            #     <td>config.secondary_worker_config.num_instances</td><td>Resize secondary
            #     worker group</td>
            #     </tr>
            #     <tr>
            #     <td>config.lifecycle_config.auto_delete_ttl</td><td>Reset MAX TTL
            #     duration</td>
            #     </tr>
            #     <tr>
            #     <td>config.lifecycle_config.auto_delete_time</td><td>Update MAX TTL
            #     deletion timestamp</td>
            #     </tr>
            #     <tr>
            #     <td>config.lifecycle_config.idle_delete_ttl</td><td>Update Idle TTL
            #     duration</td>
            #     </tr>
            #     <tr>
            #     <td>config.autoscaling_config.policy_uri</td><td>Use, stop using, or change
            #     autoscaling policies</td>
            #     </tr>
            #     </table>
            #   @param request_id [::String]
            #     Optional. A unique id used to identify the request. If the server
            #     receives two
            #     {::Google::Cloud::Dataproc::V1beta2::UpdateClusterRequest UpdateClusterRequest}
            #     requests  with the same id, then the second request will be ignored and the
            #     first {::Google::Longrunning::Operation google.longrunning.Operation} created
            #     and stored in the backend is returned.
            #
            #     It is recommended to always set this value to a
            #     [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier).
            #
            #     The id must contain only letters (a-z, A-Z), numbers (0-9),
            #     underscores (_), and hyphens (-). The maximum length is 40 characters.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::Operation]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::Operation]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def update_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1beta2::UpdateClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.update_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Dataproc::V1beta2::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "project_id" => request.project_id,
                "region" => request.region,
                "cluster_name" => request.cluster_name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.update_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.update_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @cluster_controller_stub.call_rpc :update_cluster, request, options: options do |response, operation|
                response = ::Gapic::Operation.new response, @operations_client, options: options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Deletes a cluster in a project. The returned
            # {::Google::Longrunning::Operation#metadata Operation.metadata} will be
            # [ClusterOperationMetadata](https://cloud.google.com/dataproc/docs/reference/rpc/google.cloud.dataproc.v1beta2#clusteroperationmetadata).
            #
            # @overload delete_cluster(request, options = nil)
            #   Pass arguments to `delete_cluster` via a request object, either of type
            #   {::Google::Cloud::Dataproc::V1beta2::DeleteClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Dataproc::V1beta2::DeleteClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload delete_cluster(project_id: nil, region: nil, cluster_name: nil, cluster_uuid: nil, request_id: nil)
            #   Pass arguments to `delete_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param project_id [::String]
            #     Required. The ID of the Google Cloud Platform project that the cluster
            #     belongs to.
            #   @param region [::String]
            #     Required. The Dataproc region in which to handle the request.
            #   @param cluster_name [::String]
            #     Required. The cluster name.
            #   @param cluster_uuid [::String]
            #     Optional. Specifying the `cluster_uuid` means the RPC should fail
            #     (with error NOT_FOUND) if cluster with specified UUID does not exist.
            #   @param request_id [::String]
            #     Optional. A unique id used to identify the request. If the server
            #     receives two
            #     {::Google::Cloud::Dataproc::V1beta2::DeleteClusterRequest DeleteClusterRequest}
            #     requests  with the same id, then the second request will be ignored and the
            #     first {::Google::Longrunning::Operation google.longrunning.Operation} created
            #     and stored in the backend is returned.
            #
            #     It is recommended to always set this value to a
            #     [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier).
            #
            #     The id must contain only letters (a-z, A-Z), numbers (0-9),
            #     underscores (_), and hyphens (-). The maximum length is 40 characters.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::Operation]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::Operation]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def delete_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1beta2::DeleteClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.delete_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Dataproc::V1beta2::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "project_id" => request.project_id,
                "region" => request.region,
                "cluster_name" => request.cluster_name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.delete_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.delete_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @cluster_controller_stub.call_rpc :delete_cluster, request, options: options do |response, operation|
                response = ::Gapic::Operation.new response, @operations_client, options: options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Gets the resource representation for a cluster in a project.
            #
            # @overload get_cluster(request, options = nil)
            #   Pass arguments to `get_cluster` via a request object, either of type
            #   {::Google::Cloud::Dataproc::V1beta2::GetClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Dataproc::V1beta2::GetClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload get_cluster(project_id: nil, region: nil, cluster_name: nil)
            #   Pass arguments to `get_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param project_id [::String]
            #     Required. The ID of the Google Cloud Platform project that the cluster
            #     belongs to.
            #   @param region [::String]
            #     Required. The Dataproc region in which to handle the request.
            #   @param cluster_name [::String]
            #     Required. The cluster name.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::Dataproc::V1beta2::Cluster]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::Dataproc::V1beta2::Cluster]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def get_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1beta2::GetClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.get_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Dataproc::V1beta2::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "project_id" => request.project_id,
                "region" => request.region,
                "cluster_name" => request.cluster_name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.get_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.get_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @cluster_controller_stub.call_rpc :get_cluster, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Lists all regions/\\{region}/clusters in a project alphabetically.
            #
            # @overload list_clusters(request, options = nil)
            #   Pass arguments to `list_clusters` via a request object, either of type
            #   {::Google::Cloud::Dataproc::V1beta2::ListClustersRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Dataproc::V1beta2::ListClustersRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload list_clusters(project_id: nil, region: nil, filter: nil, page_size: nil, page_token: nil)
            #   Pass arguments to `list_clusters` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param project_id [::String]
            #     Required. The ID of the Google Cloud Platform project that the cluster
            #     belongs to.
            #   @param region [::String]
            #     Required. The Dataproc region in which to handle the request.
            #   @param filter [::String]
            #     Optional.  A filter constraining the clusters to list. Filters are
            #     case-sensitive and have the following syntax:
            #
            #     field = value [AND [field = value]] ...
            #
            #     where **field** is one of `status.state`, `clusterName`, or `labels.[KEY]`,
            #     and `[KEY]` is a label key. **value** can be `*` to match all values.
            #     `status.state` can be one of the following: `ACTIVE`, `INACTIVE`,
            #     `CREATING`, `RUNNING`, `ERROR`, `DELETING`, or `UPDATING`. `ACTIVE`
            #     contains the `CREATING`, `UPDATING`, and `RUNNING` states. `INACTIVE`
            #     contains the `DELETING` and `ERROR` states.
            #     `clusterName` is the name of the cluster provided at creation time.
            #     Only the logical `AND` operator is supported; space-separated items are
            #     treated as having an implicit `AND` operator.
            #
            #     Example filter:
            #
            #     status.state = ACTIVE AND clusterName = mycluster
            #     AND labels.env = staging AND labels.starred = *
            #   @param page_size [::Integer]
            #     Optional. The standard List page size.
            #   @param page_token [::String]
            #     Optional. The standard List page token.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1beta2::Cluster>]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1beta2::Cluster>]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def list_clusters request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1beta2::ListClustersRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.list_clusters.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Dataproc::V1beta2::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "project_id" => request.project_id,
                "region" => request.region
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.list_clusters.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.list_clusters.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @cluster_controller_stub.call_rpc :list_clusters, request, options: options do |response, operation|
                response = ::Gapic::PagedEnumerable.new @cluster_controller_stub, :list_clusters, request, response, operation, options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Gets cluster diagnostic information. The returned
            # {::Google::Longrunning::Operation#metadata Operation.metadata} will be
            # [ClusterOperationMetadata](https://cloud.google.com/dataproc/docs/reference/rpc/google.cloud.dataproc.v1beta2#clusteroperationmetadata).
            # After the operation completes,
            # {::Google::Longrunning::Operation#response Operation.response}
            # contains
            # {::Google::Protobuf::Empty Empty}.
            #
            # @overload diagnose_cluster(request, options = nil)
            #   Pass arguments to `diagnose_cluster` via a request object, either of type
            #   {::Google::Cloud::Dataproc::V1beta2::DiagnoseClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Dataproc::V1beta2::DiagnoseClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload diagnose_cluster(project_id: nil, region: nil, cluster_name: nil)
            #   Pass arguments to `diagnose_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param project_id [::String]
            #     Required. The ID of the Google Cloud Platform project that the cluster
            #     belongs to.
            #   @param region [::String]
            #     Required. The Dataproc region in which to handle the request.
            #   @param cluster_name [::String]
            #     Required. The cluster name.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::Operation]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::Operation]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def diagnose_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1beta2::DiagnoseClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.diagnose_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Dataproc::V1beta2::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "project_id" => request.project_id,
                "region" => request.region,
                "cluster_name" => request.cluster_name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.diagnose_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.diagnose_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @cluster_controller_stub.call_rpc :diagnose_cluster, request, options: options do |response, operation|
                response = ::Gapic::Operation.new response, @operations_client, options: options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Configuration class for the ClusterController API.
            #
            # This class represents the configuration for ClusterController,
            # providing control over timeouts, retry behavior, logging, transport
            # parameters, and other low-level controls. Certain parameters can also be
            # applied individually to specific RPCs. See
            # {::Google::Cloud::Dataproc::V1beta2::ClusterController::Client::Configuration::Rpcs}
            # for a list of RPCs that can be configured independently.
            #
            # Configuration can be applied globally to all clients, or to a single client
            # on construction.
            #
            # # Examples
            #
            # To modify the global config, setting the timeout for create_cluster
            # to 20 seconds, and all remaining timeouts to 10 seconds:
            #
            #     ::Google::Cloud::Dataproc::V1beta2::ClusterController::Client.configure do |config|
            #       config.timeout = 10.0
            #       config.rpcs.create_cluster.timeout = 20.0
            #     end
            #
            # To apply the above configuration only to a new client:
            #
            #     client = ::Google::Cloud::Dataproc::V1beta2::ClusterController::Client.new do |config|
            #       config.timeout = 10.0
            #       config.rpcs.create_cluster.timeout = 20.0
            #     end
            #
            # @!attribute [rw] endpoint
            #   The hostname or hostname:port of the service endpoint.
            #   Defaults to `"dataproc.googleapis.com"`.
            #   @return [::String]
            # @!attribute [rw] credentials
            #   Credentials to send with calls. You may provide any of the following types:
            #    *  (`String`) The path to a service account key file in JSON format
            #    *  (`Hash`) A service account key as a Hash
            #    *  (`Google::Auth::Credentials`) A googleauth credentials object
            #       (see the [googleauth docs](https://googleapis.dev/ruby/googleauth/latest/index.html))
            #    *  (`Signet::OAuth2::Client`) A signet oauth2 client object
            #       (see the [signet docs](https://googleapis.dev/ruby/signet/latest/Signet/OAuth2/Client.html))
            #    *  (`GRPC::Core::Channel`) a gRPC channel with included credentials
            #    *  (`GRPC::Core::ChannelCredentials`) a gRPC credentails object
            #    *  (`nil`) indicating no credentials
            #   @return [::Object]
            # @!attribute [rw] scope
            #   The OAuth scopes
            #   @return [::Array<::String>]
            # @!attribute [rw] lib_name
            #   The library name as recorded in instrumentation and logging
            #   @return [::String]
            # @!attribute [rw] lib_version
            #   The library version as recorded in instrumentation and logging
            #   @return [::String]
            # @!attribute [rw] channel_args
            #   Extra parameters passed to the gRPC channel. Note: this is ignored if a
            #   `GRPC::Core::Channel` object is provided as the credential.
            #   @return [::Hash]
            # @!attribute [rw] interceptors
            #   An array of interceptors that are run before calls are executed.
            #   @return [::Array<::GRPC::ClientInterceptor>]
            # @!attribute [rw] timeout
            #   The call timeout in seconds.
            #   @return [::Numeric]
            # @!attribute [rw] metadata
            #   Additional gRPC headers to be sent with the call.
            #   @return [::Hash{::Symbol=>::String}]
            # @!attribute [rw] retry_policy
            #   The retry policy. The value is a hash with the following keys:
            #    *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
            #    *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
            #    *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
            #    *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
            #       trigger a retry.
            #   @return [::Hash]
            # @!attribute [rw] quota_project
            #   A separate project against which to charge quota.
            #   @return [::String]
            #
            class Configuration
              extend ::Gapic::Config

              config_attr :endpoint,      "dataproc.googleapis.com", ::String
              config_attr :credentials,   nil do |value|
                allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
                allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC
                allowed.any? { |klass| klass === value }
              end
              config_attr :scope,         nil, ::String, ::Array, nil
              config_attr :lib_name,      nil, ::String, nil
              config_attr :lib_version,   nil, ::String, nil
              config_attr(:channel_args,  { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil)
              config_attr :interceptors,  nil, ::Array, nil
              config_attr :timeout,       nil, ::Numeric, nil
              config_attr :metadata,      nil, ::Hash, nil
              config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
              config_attr :quota_project, nil, ::String, nil

              # @private
              def initialize parent_config = nil
                @parent_config = parent_config unless parent_config.nil?

                yield self if block_given?
              end

              ##
              # Configurations for individual RPCs
              # @return [Rpcs]
              #
              def rpcs
                @rpcs ||= begin
                  parent_rpcs = nil
                  parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
                  Rpcs.new parent_rpcs
                end
              end

              ##
              # Configuration RPC class for the ClusterController API.
              #
              # Includes fields providing the configuration for each RPC in this service.
              # Each configuration object is of type `Gapic::Config::Method` and includes
              # the following configuration fields:
              #
              #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
              #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers
              #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
              #     include the following keys:
              #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
              #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
              #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
              #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
              #         trigger a retry.
              #
              class Rpcs
                ##
                # RPC-specific configuration for `create_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :create_cluster
                ##
                # RPC-specific configuration for `update_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :update_cluster
                ##
                # RPC-specific configuration for `delete_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :delete_cluster
                ##
                # RPC-specific configuration for `get_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :get_cluster
                ##
                # RPC-specific configuration for `list_clusters`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :list_clusters
                ##
                # RPC-specific configuration for `diagnose_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :diagnose_cluster

                # @private
                def initialize parent_rpcs = nil
                  create_cluster_config = parent_rpcs.create_cluster if parent_rpcs.respond_to? :create_cluster
                  @create_cluster = ::Gapic::Config::Method.new create_cluster_config
                  update_cluster_config = parent_rpcs.update_cluster if parent_rpcs.respond_to? :update_cluster
                  @update_cluster = ::Gapic::Config::Method.new update_cluster_config
                  delete_cluster_config = parent_rpcs.delete_cluster if parent_rpcs.respond_to? :delete_cluster
                  @delete_cluster = ::Gapic::Config::Method.new delete_cluster_config
                  get_cluster_config = parent_rpcs.get_cluster if parent_rpcs.respond_to? :get_cluster
                  @get_cluster = ::Gapic::Config::Method.new get_cluster_config
                  list_clusters_config = parent_rpcs.list_clusters if parent_rpcs.respond_to? :list_clusters
                  @list_clusters = ::Gapic::Config::Method.new list_clusters_config
                  diagnose_cluster_config = parent_rpcs.diagnose_cluster if parent_rpcs.respond_to? :diagnose_cluster
                  @diagnose_cluster = ::Gapic::Config::Method.new diagnose_cluster_config

                  yield self if block_given?
                end
              end
            end
          end
        end
      end
    end
  end
end
